/**********************************************************************
$Id: nexus_utp_private.h,v 1.3 1997/10/21 14:40:43 freedman Exp $

$Source: /nfs/globus1/src/master/nexus_utp/nexus_utp_private.h,v $

$Log: nexus_utp_private.h,v $
Revision 1.3  1997/10/21 14:40:43  freedman
Finishing renaming of defines and variables.

Revision 1.2  1997/10/20 23:57:03  freedman
Started renaming of functions from UTP_ to nexus_utp_

Revision 1.1  1997/07/23 22:04:09  tuecke
First pass at integrating Dave Kohr UTP timing package into nexus

Revision 1.5  1995/11/28 21:51:02  tuecke
Added SGI Irix support

Revision 1.4  1994/11/08  06:36:28  kohr
Port to Paragon using dclock().

Revision 1.3  1994/11/07  15:38:15  patton
added functionality for Solaris high-resolution timer..

Revision 1.2  1994/11/03  19:52:50  kohr
Move current source from RCS to CVS control.

Revision 1.1  1994/10/25  20:42:17  tuecke
An initial version of Dave Kohr's timing package

Private declarations for the Unnamed Timing Package (UTP).
**********************************************************************/

/*
Pre-CVS version information:

Revision 1.8  1994/11/03  02:24:36  kohr
Added support for key/value pairs with UTP_set_attribute().

Revision 1.7  1994/11/01  02:29:31  kohr
Added timer naming and disabling/enabling; other clean-up.

Revision 1.6  1994/10/25  06:27:17  kohr
Use gettimer() on RS6000.

Revision 1.5  1994/10/10  23:53:56  kohr
Fixed big bug in UTP_set_filename().

Revision 1.4  1994/10/07  19:25:26  kohr
Minor doc. change.

Revision 1.3  1994/10/07  03:55:26  kohr
Use #error, added UTP_timeToDouble().

Revision 1.2  1994/09/15  00:24:13  kohr
Remove trailing comma in enum-value list.

Revision 1.1  1994/09/14  06:03:55  kohr
Initial revision
*/

#ifndef _nexus_utp_private_h_
#define _nexus_utp_private_h_

#include "nexus_utp.h"

/**********************************************************************
Machine-dependent definitions.
**********************************************************************/

/*
Supported machine types are as follows:

UNIX : generic Unix; assumes BSD 4.3-compatible gettimeofday(2) and
	"struct timeval" from <sys/time.h>.  I have not yet seen a modern
	Unix worksation which doesn't have this.

RS6000 : IBM RS6000 running AIX 3.2 or higher.  Relies on the gettimer()
	routine, which is supposed to be a standard (yet the IBM "info"
	pages say it may change!).  Clock frequency is supposed to be
	256 nanosec.
*/

/*
Check that at least one supported machine type macro was defined.
*/

#if !defined(UNIX) && !defined(RS6000) && !defined(SOLHR) && \
	!defined(SPARCSUNOS41) && !defined(PARAGON)
#error "No machine type was defined."
#endif


/*
nexus_utp_TimeValue_t is a machine-dependent type representing a time, at the
highest resolution available.
*/

#if defined(UNIX) || defined(SPARCSUNOS41)

#include <sys/time.h>

#ifdef BSDGETTIMEOFDAY
extern int
BSDgettimeofday(struct timeval *tvp, struct timezone *tzp);
#else
extern int
gettimeofday(struct timeval *tvp, struct timezone *tzp);
#endif

typedef struct timeval nexus_utp_TimeValue_t;

#endif /* #ifdef UNIX */


#ifdef RS6000

/*
See also comments on RS6000 version of nexus_utp_readTime() in nexus_utp_main.c.
*/

#include <sys/time.h>

typedef struct timestruc_t nexus_utp_TimeValue_t;

#endif	/* #ifdef RS6000 */


#ifdef SOLHR

#include <sys/time.h>

typedef hrtime_t nexus_utp_TimeValue_t;

#endif


#ifdef PARAGON

#include <nx.h>

typedef double nexus_utp_TimeValue_t;

#endif


/**********************************************************************
Machine-independent definitions.
**********************************************************************/

extern int errno;		/* These are needed for all systems. */
extern char *sys_errlist[];


/*
nexus_utp_TimerState represents the current state of a timer.  A timer which is
either "stopped" or "running" is implicitly enabled.
*/

typedef enum _nexus_utp_TimerState {
	NEXUS_UTP_TIMER_STOPPED,
	NEXUS_UTP_TIMER_RUNNING,
	NEXUS_UTP_TIMER_DISABLED
} nexus_utp_TimerState;


/*
nexus_utp_Timer_t contains all data associated with a timer.
*/

typedef struct _nexus_utp_Timer_t {
	nexus_utp_TimerState state;
	nexus_utp_TimeValue_t startTime;/* If running, when did it start? */
					/* Total time accumulated. */
	nexus_utp_TimeValue_t accumulatedTime;
	unsigned long numEvents;	/* Number of timed events
					   accumulated into the timer. */
	char *name;			/* Human-readable name. */
} nexus_utp_Timer_t;


/*
Attributes (key/value pairs) are stored in a linked-list structure.
*/

struct _nexus_utp_Attribute_t;		/* Forward declaration. */

typedef struct _nexus_utp_Attribute_t {
	char *key;
	char *value;
	struct _nexus_utp_Attribute_t *next;
} nexus_utp_Attribute_t;


/*
Masks to select fields of the nexus_utp_init "mode" parameter.
*/

#define NEXUS_UTP_MODE_SHARING_FIELD 0x1


/**********************************************************************
Private but global functions, to be used only internally by the UTP
package.
**********************************************************************/

/*
Read current clock time, in a machine-dependent way; store result in *tv.
*/

extern void
nexus_utp_readTime(nexus_utp_TimeValue_t *tv);

/*
Place elapsed time between *start and *end into *diff (machine-dependent).
It is permissible for start and/or end to be identical to diff.
*/

extern void
nexus_utp_timeDifference(nexus_utp_TimeValue_t *diff, const nexus_utp_TimeValue_t *start,
		   const nexus_utp_TimeValue_t *end);

/*
Accumulate *newElapsed time into *oldElapsed (machine-dependent).
*/

extern void
nexus_utp_timeAdd(nexus_utp_TimeValue_t *oldElapsed,
	    const nexus_utp_TimeValue_t *newElapsed);

/*
Set *tv to time zero (machine-dependent).
*/

extern void
nexus_utp_timeZero(nexus_utp_TimeValue_t *tv);


/*
Convert *tv to its double-precision floating-point representation; store it
in *time, store number of significant digits after the decimal place in
*precision.  Machine-dependent.
*/

extern void
nexus_utp_timeToDouble(double *time, int *precision, const nexus_utp_TimeValue_t *tv);


/*
Convert *tv to its floating-point string representation, with seconds as
the units; store result in timeString.  Machine-dependent.
*/

extern void
nexus_utp_timeToString(char timeString[], const nexus_utp_TimeValue_t *tv);


/*
Emit the warning message messageStr in some appropriate way.  messageStr is
a printf()-format output specfier string; the "..." represents data to be
printed using the specifier.
*/

extern void
nexus_utp_warn(const char *messageStr, ...);


/**********************************************************************
Private but global variables, to be used only internally by the UTP
package.
**********************************************************************/

extern char *nexus_utp_outFilename;		/* Name of output dump file. */
extern unsigned nexus_utp_numTimers;		/* Number of timers in use. */
extern nexus_utp_Timer_t *nexus_utp_timers;		/* Array for the timers. */
extern nexus_utp_Attribute_t *nexus_utp_attributes;	/* Key/value pairs (comments). */


#endif /* #ifndef _nexus_utp_private_h_ */

