/******************************************************************************
Description:

  Classes to provide simple Nexus functionality

CVS Information:

  $Source$
  $Date$
  $Revision$
  $State$
  $Author$
******************************************************************************/

#if !defined(NEXUS_INCLUDE_NEXUS)
#define NEXUS_INCLUDE_NEXUS 1

/******************************************************************************
			     Include header files
******************************************************************************/
#include "CIF_config.h"

/******************************************************************************
				Macroized Types
******************************************************************************/

/*
 * Method argument: value is used and will *not be modified*
 */
#if !defined(ARG_IN)
#   define ARG_IN
#endif

/*
 * Method argument: value is used and *may be modified*
 */
#if !defined(ARG_INMOD)
#   define ARG_INMOD
#endif

/*
 * Method argument: value is not used, but may be modified to contain some
 * result when the method returns
 */
#if !defined(ARG_OUT)
#   define ARG_OUT
#endif

/*
 * Method argument: value is used, and may be modified to contain some
 * result when the method returns
 */
#if !defined(ARG_INOUT)
#   define ARG_INOUT
#endif


/******************************************************************************
			       Type definitions
******************************************************************************/
typedef unsigned char Nexus_Byte;

typedef unsigned long Nexus_Size;

#if defined(HAVE_BOOL)
typedef bool Nexus_Bool;
#else
enum Nexus_Bool
{
    false = 0,
    true = 1
};
#endif


/******************************************************************************
			      Define Nexus class
******************************************************************************/
class
Nexus
{
    public: static
    Nexus_Bool
    activate();

    public: static
    Nexus_Bool
    deactivate();
    
    public:
    enum Status
    {
	/* The operation was successful */
	STATUS_SUCCESS = 0,

	/* The operation failed */
	STATUS_FAILURE = 1,

	/* The operation failed because the object had already been activated
           by some previous operation (ex: the connection had already been
           established) */
	STATUS_OBJECT_ACTIVE = 2,

	/* The operation failed because some previous operation deactived the
           object (ex: the connection was closed in a previous operation, so
           any subsequent sends will fail) */
	STATUS_OBJECT_INACTIVE = 3,

	/* The object being accessed has been previously deleted */
	STATUS_OBJECT_DELETED = 4,

	/* An out of memory condition occurred */
	STATUS_INSUFFICIENT_MEMORY = 5,

	/* The format of the specified URL was not valid */
	STATUS_URL_FORMAT_BAD = 6,

	/* The scheme of the specified URL is not supported */
	STATUS_URL_SCHEME_UNSUPPORTED = 6,

	/* An internal error occurred (shouldn't happen).  Please contact the
           author. */
	STATUS_INTERNAL_ERROR = -1
    };

    public:
    static Status &			status;
};

#endif /* NEXUS_INCLUDE_NEXUS */
