/******************************************************************************
Nexus_Startpoint.H

Description:

  Classes to provide simple Nexus startpoint functionality

CVS Information:

  $Source$
  $Date$
  $Revision$
  $State$
  $Author$
******************************************************************************/

#if !defined(NEXUS_INCLUDE_NEXUS_STARTPOINT)
#define NEXUS_INCLUDE_NEXUS_STARTPOINT 1

/******************************************************************************
			     Include header files
******************************************************************************/
#include "Nexus.H"
#include "nexus.h"


/******************************************************************************
			       Class prototypes
******************************************************************************/
class Nexus_Endpoint;


/******************************************************************************
			 Define Nexus_Startpoint class
******************************************************************************/
class
Nexus_Startpoint
{
    /**************************************************************************
				    API methods
    **************************************************************************/

    /*
     * Nexus_Startpoint::Nexus_Startpoint()
     */
    public:
    Nexus_Startpoint();

    /*
     * Nexus_Startpoint::activate()
     */
    public:
    Nexus_Bool
    activate(
	ARG_IN char *			host,
	ARG_IN unsigned short		port);
    
    /*
     * Nexus_Startpoint::Nexus_Startpoint()
     */
    public:
    Nexus_Bool
    activate(
	ARG_IN Nexus_Endpoint &		endpoint);
    
    /*
     * Nexus_Startpoint::send()
     */
    public:
    Nexus_Bool
    send(
	ARG_INOUT Nexus_Send_Buffer &	buffer);
    
    /*
     * Nexus_Startpoint::deactivate()
     */
    public:
    Nexus_Bool
    deactivate();
    
    /*
     * Nexus_Startpoint::~Nexus_Startpoint()
     */
    public:
    ~Nexus_Startpoint();


    /**************************************************************************
		       Internal methods and data structures
    **************************************************************************/

    /*
     * Objects which need access to our private methods
     */
    friend class Nexus_Receive_Buffer;
    friend class Nexus_Send_Buffer;
    
    /*
     * State of the startpoint object
     */
    enum Object_State
    {
	OBJECT_STATE_INACTIVE,
	OBJECT_STATE_ACTIVE,
	OBJECT_STATE_DELETED
    };

    /*
     * Nexus_Startpoint::l_deactivate()
     */
    private:
    Nexus_Bool
    l_deactivate();
    
    /*
     * Nexus_Startpoint::sizeof_Internal_Startpoint()
     */
    private:
    Nexus_Size
    sizeof_Internal_Startpoint();
    
    /*
     * Nexus_Startpoint::get_Internal_Startpoint()
     */
    private:
    Nexus_Bool
    get_Internal_Startpoint(
	ARG_INOUT nexus_buffer_t *	nx_buffer);
    
    /*
     * Nexus_Startpoint::put_Internal_Startpoint()
     */
    private:
    Nexus_Bool
    put_Internal_Startpoint(
	ARG_INOUT nexus_buffer_t *	nx_buffer);

    /*
     * Nexus_Startpoint::verify_Object_State()
     */
    private:
    Nexus::Status
    verify_Object_State(
	ARG_IN Object_State		desired_state);
	
    /*
     * Internal data members
     */
    private:

    /* mutex to protect listener data structures */
    nexus_mutex_t			mutex;

    /* nexus startpoint */
    nexus_startpoint_t			sp;
    
    /* state of the endpoint */
    Object_State			object_state;
};


#endif /* NEXUS_INCLUDE_NEXUS_STARTPOINT */
